/*
	Copyright 2013-2014, Marten de Vries

	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/

"use strict";

require("./compat.js");
var extend = require("extend");
var bridge = require("./bridge.js");

var PouchDB = require("pouchdb");

var GQL = require("pouchdb-gql");
var geopouch = require("geopouch");
var QuickSearch = require("pouchdb-quick-search");
var search = require("pouchdb-search");
require("pouchdb-all-dbs")(PouchDB);

var Validation = require("pouchdb-validation");
var Show = require("pouchdb-show");
var List = require("pouchdb-list");
var Update = require("pouchdb-update");
var Replicator = require("pouchdb-replicator");
var Rewrite = require("pouchdb-rewrite");
var Auth = require("pouchdb-auth");

//remove the _pouch_ prefix, it's not needed anyway.
PouchDB.prefix = "";

//register 3rd party plugins (if necessary)
PouchDB.plugin(GQL);
PouchDB.plugin(geopouch);
PouchDB.plugin(QuickSearch);
PouchDB.prototype.quickSearch = PouchDB.prototype.search;
PouchDB.plugin({search: search});

//register 'home made' plugins
PouchDB.plugin(Validation);
PouchDB.plugin(Show);
PouchDB.plugin(List);
PouchDB.plugin(Update);
PouchDB.plugin(Replicator);
PouchDB.plugin(Rewrite);
PouchDB.plugin(Auth);

//expose relevant api
global.PouchDB = PouchDB;
extend(global, bridge);
